package com.extremelogic.common.jclap.sample;

import com.extremelogic.common.jclap.Argument;
import com.extremelogic.common.jclap.ArgumentRetriever;

public class SampleArguments {

    /**
     * @param args
     */
    public static void main(String[] args) {
        args = new String[]{"--silent", "--tablename", "employee", "role", "--database", "teradata"};
        demoValueRetrieval(args);
        
        args = new String[]{"@silent", "@tablename", "employee", "role", "@database", "teradata"};
        demoValueRetrievalWithCustomDelimiter(args);
        
        demoDisplayOptions(args);
        
        args = new String[]{"--silent", "--tablename", "employee", "--database", "teradata"};
        demoHandleExceptionOutside(args);
        
        args = new String[]{"-silent", "--tablename", "employee", "role", "--database", "teradata"};
        demoHandleExceptionOutside(args);
    }
  
    private static void demoHandleExceptionOutside(String[] args) {
        System.out.println();
        System.out.println("[demoHandleExceptionOutside]");
        
        Argument arg = null;

        arg = new Argument(args);
        arg.addBooleanArgument("silent", "Enable silent processing.");
        arg.addBooleanArgument("enablelog", "Enable logging.");
        arg.addArgument("tablename", "Table to be populated.", 2);
        arg.addArgument("database", "Database vendor to use.", 1);
        arg.setProgramDescription("Populates a table with test data.");
        
        arg.setShowOptions(false);
        arg.setRethrowException(true);

        try {
            arg.processArguments();
        } catch (Exception e) {
           System.out.println("Exception occurred. " + e.getMessage());  
        }
        
        if(arg.isExceptionOccured()) {
            arg.displayOptions();
        }
    }    
    
    private static void demoValueRetrievalWithCustomDelimiter(String[] args) {
        System.out.println();
        System.out.println("[demoValueRetrievalWithCustomDelimiter]");
        
        Argument arg = null;
        ArgumentRetriever ar = null;

        arg = new Argument(args);
        arg.setDelimiter("@");
        arg.addBooleanArgument("silent", "Enable silent processing.");
        arg.addBooleanArgument("enablelog", "Enable logging.");
        arg.addArgument("tablename", "Table to be populated.", 2);
        arg.addArgument("database", "Database vendor to use.", 1);
        arg.setProgramDescription("Populates a table with test data.");

        try {
            arg.processArguments();
        } catch (Exception e) {
           // do nothing because no exception is expected
        }
        
        ar = arg.getArgumentRetriever();

        String aa[];

        aa = ar.getOptionValues("tablename");
        for (int z = 0; z < aa.length; z++) {
            System.out.println("  option tablename value: " + aa[z]);
        }

        String a;
        a = ar.getOptionValue("database");
        System.out.println("  option database value: " + a);
        
        String b;
        b = ar.getOptionValue("silent");
        System.out.println("  option silent value: " + b);
        
        String c;
        c = ar.getOptionValue("enablelog");
        System.out.println("  option enablelog value: " + c);
    }    
    
    private static void demoValueRetrieval(String[] args) {
        System.out.println();
        System.out.println("[demoValueRetrieval]");
        
        Argument arg = null;
        ArgumentRetriever ar = null;

        arg = new Argument(args);
        arg.addBooleanArgument("silent", "Enable silent processing.");
        arg.addBooleanArgument("enablelog", "Enable logging.");
        arg.addArgument("tablename", "Table to be populated.", 2);
        arg.addArgument("database", "Database vendor to use.", 1);
        arg.setProgramDescription("Populates a table with test data.");

        try {
            arg.processArguments();
        } catch (Exception e) {
           // do nothing because no exception is expected
        }
        
        ar = arg.getArgumentRetriever();

        String aa[];

        aa = ar.getOptionValues("tablename");
        for (int z = 0; z < aa.length; z++) {
            System.out.println("  option tablename value: " + aa[z]);
        }

        String a;
        a = ar.getOptionValue("database");
        System.out.println("  option database value: " + a);
        
        String b;
        b = ar.getOptionValue("silent");
        System.out.println("  option silent value: " + b);
        
        String c;
        c = ar.getOptionValue("enablelog");
        System.out.println("  option enablelog value: " + c);
    }

    /**
     * <p>Shows the typical display of options based on the parameters passed.</p>
     * 
     * @param args The argument input
     */
    private static void demoDisplayOptions(String[] args) {
        System.out.println();
        System.out.println("[demoDisplayOptions]");
        
        Argument arg = null;

        arg = new Argument(args);
        arg.addBooleanArgument("silent", "Enable silent processing.");
        arg.addBooleanArgument("enablelog", "Enable logging.");
        arg.addArgument("tablename", "Table to be populated.", 2);
        arg.addArgument("database", "Database vendor to use.", 1);
        arg.setProgramDescription("Populates a table with test data.");
        
        arg.displayOptions();
    }   
}
